Edison plug-in for Thonny
==========================

This is a plug-in for `Thonny IDE <https://thonny.org>`_, which adds possibility to 
program `Edison robot <https://meetedison.com/>`_ 
in a `Python-like language <https://meetedison.com/robot-programming-software/edpy/>`_ 
using `EdPy library <https://github.com/Bdanilko/EdPy/>`_.

In other words -- it's an off-line replacement for https://www.edpyapp.com/. 

Installation
------------
#. Install Thonny 3.2 or later
#. Select "Tools => Manage plug-ins"...
#. enter ``thonny-edison`` to search box and press ENTER
#. Install the plug-in
#. Restart Thonny

After this you should see Edison programming command in Tools menu

Usage
-----
* Save Edison scripts as local py-files.
* Autocomplete is available on ``Ed``-module. 
* When you are done, use "Tools => Send current script to Edison".
